@@ -1,12 +1,24 @@
+from abc import ABC, abstractmethod
 import datetime
 import logging
 import inspect
 import json
 import time
+from typing import Union
 
 logger = logging.getLogger(__name__)
 
 
+class JSONAble(ABC):
+    """
+    Generic interface for JSON-able objects.
+    """
+
+    @abstractmethod
+    def to_json(self) -> Union[str, list, dict]:
+        raise NotImplementedError()
+
+
 class Message(object):
     """ Message generic class """
 
@@ -48,7 +60,14 @@ class Message(object):
             if value is not None:
                 return value
 
-            return super().default(obj)
+            if isinstance(obj, JSONAble):
+                return obj.to_json()
+
+            try:
+                return super().default(obj)
+            except Exception as e:
+                logger.warning('Could not serialize object type {}: {}: {}'.format(
+                    type(obj), str(e), obj))
 
     def __init__(self, timestamp=None, *args, **kwargs):
         self.timestamp = timestamp or time.time()
